@@ -1,12 +1,13 @@
-import json
 import logging
 from dataclasses import dataclass
 from datetime import datetime
+import json
 from enum import Enum
 from typing import Generic, List, TypeVar
 
 from k9.internal.k9_core_client import K9Core
 from jsonschema import Draft7Validator
+import uuid
 
 logging.basicConfig(
     format='[K9-%(levelname)s] msg=%(message)s', level=logging.DEBUG)
@@ -44,7 +45,7 @@ class InfraProperties:
     docker_id: str
     ip: str
     hostname: str
-    
+
     # def __str__(self):
     #     return f'{self.__dict__}'
 
@@ -53,20 +54,16 @@ class InfraProperties:
 class LogMessage(Generic[T]):
     app_name: str
     correlation_id: str
-    timestamp: datetime
+    log_level: int
     message: str
-    log_level: str
     # infrastructure: InfraProperties
     # attributes: T
-    
+
     def __str__(self):
         msg = {
             "app_name": self.app_name,
             "correlation_id": self.correlation_id,
-            "timestamp": self.timestamp,
-            "message": self.message,
             "log_level": self.log_level,
-            "timestamp": self.timestamp.timestamp()
         }
         return f'{msg}'
 
@@ -85,38 +82,42 @@ class LogError:
 
 class K9Logger:
     schema: Draft7Validator
+    app_name: str
 
-    # def __init__(self):
-    #     with open('./log.schema.json') as jsonSchema:
-    #         schema = Draft7Validator(json.load(jsonSchema))
-    #         self.schema = schema
+    def __init__(self, app_name: str):
+        self.app_name = app_name
 
     # def __isValidMessage(self, message: str) -> bool:
     #     for err in self.schema.iter_errors(message):
     #         print("Teste: ", err)
     #     return True
 
-    def log(self, message: LogMessage):
+    def __get_message(self, message: str, log_level: int, correlation_id: str):
+        args = {
+            "app_name": self.app_name,
+            "correlation_id": correlation_id,
+            "log_level": logging.getLevelName(log_level),
+            "message": message
+        }
+
+        if args["correlation_id"] == '':
+            args["correlation_id"] = str(uuid.uuid4())
+
+        return LogMessage(**args)
+
+    def log(self, message: str, log_level: int, correlation_id: str = ''):
         # self.__isValidMessage(message)
-        K9Core().sendRequest(modelTeste.__dict__)
-        logging.info(message)
+        msg = self.__get_message(
+            message=message, correlation_id=correlation_id, log_level=log_level)
+        K9Core().sendRequest(message=json.dumps(msg.__dict__))
+        logging.log(level=log_level, msg=message)
 
 
 if __name__ == "__main__":
-    attr = Teste(A="", B=432)
-    infra = InfraProperties(docker_id="", hostname="", ip="", k8s_cluster_name="",
-                            k8s_container_id="", k8s_container_name="", k8s_deployment="", k8s_namespace="")
-    modelTeste = LogMessage[Teste](
-        message="", app_name="", correlation_id="", log_level="", timestamp=datetime.utcnow())
-    K9Core().sendRequest(modelTeste.__dict__)
-    K9Logger().log(modelTeste)
-    # K9Core().sendRequest(dict(teste1="", teste2=123))
-    
-# if __name__ == "__main__":
-#     attr = Teste(A="", B=432)
-#     infra = InfraProperties(docker_id="", hostname="", ip="", k8s_cluster_name="",
-#                             k8s_container_id="", k8s_container_name="", k8s_deployment="", k8s_namespace="")
-#     modelTeste = LogMessage[Teste](
-#         message="", infrastructure=infra, attributes=attr, app_name="", correlation_id="", log_level="", timestamp=datetime.utcnow())
-
-#     K9Core().sendRequest(modelTeste.__dict__)
+    # attr = Teste(A="", B=432)
+    # infra = InfraProperties(docker_id="", hostname="", ip="", k8s_cluster_name="",
+    #                         k8s_container_id="", k8s_container_name="", k8s_deployment="", k8s_namespace="")
+    # modelTeste = LogMessage[Teste](
+    #     message="", app_name="", correlation_id="", log_level="", timestamp=datetime.utcnow().timestamp())
+    # K9Core().sendRequest(modelTeste)
+    K9Logger(app_name="hello-world").log(log_level=logging.INFO, message="Teste")
